@@ -19,7 +19,9 @@ chrome.test.runTests([
 
   function bookmarks() {
     try {
-      chrome.bookmarks.get("1", function(results) {
+      // Use getRecent() instead of get("1") because desktop Android doesn't
+      // create the bookmark bar (id "1") by default.
+      chrome.bookmarks.getRecent(1, function (results) {
         chrome.test.fail();
       });
     } catch (e) {
@@ -30,15 +32,27 @@ chrome.test.runTests([
   // Tabs functionality should be enabled even if the tabs permissions are not
   // present.
   function tabs() {
-    try {
-      chrome.tabs.create({'url': '1'}, function(tab) {
-        // Tabs strip sensitive data without permissions.
-        chrome.test.assertFalse('url' in tab);
+    // TODO(crbug.com/371432155): Port to desktop Android when chrome.tabs API
+    // is available.
+    const getPlatformInfo = new Promise((resolve) => {
+      chrome.runtime.getPlatformInfo(info => resolve(info.os == 'android'));
+    });
+    getPlatformInfo.then(isAndroid => {
+      if (isAndroid) {
         chrome.test.succeed();
-      });
-    } catch (e) {
-      chrome.test.fail();
-    }
+        return;
+      } else {
+        try {
+          chrome.tabs.create({'url': '1'}, function(tab) {
+            // Tabs strip sensitive data without permissions.
+            chrome.test.assertFalse('url' in tab);
+            chrome.test.succeed();
+          });
+        } catch (e) {
+          chrome.test.fail();
+        }
+      }
+    });
   },
 
   function idle() {
