@@ -31,8 +31,8 @@ export class TestSmbBrowserProxy extends TestBrowserProxy implements
     this.methodCalled('startDiscovery');
   }
 
-  updateCredentials(mountId: string, username: string, password: string): void {
-    this.methodCalled('updateCredentials', mountId, username, password);
+  updateCredentials(username: string, password: string): void {
+    this.methodCalled('updateCredentials', username, password);
   }
 
   hasAnySmbMountedBefore(): Promise<boolean> {
