@@ -2,7 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-import type {AutocompleteMatch} from 'chrome://resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
+import {stringToMojoString16} from 'chrome://resources/js/mojo_type_util.js';
+import type {AutocompleteMatch, AutocompleteResult} from 'chrome://resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
 import {assertEquals} from 'chrome://webui-test/chai_assert.js';
 
 export function createAutocompleteMatch(): AutocompleteMatch {
@@ -26,6 +27,7 @@ export function createAutocompleteMatch(): AutocompleteMatch {
     iconUrl: {url: ''},
     imageDominantColor: '',
     imageUrl: '',
+    isNoncannedAimSuggestion: false,
     removeButtonA11yLabel: {data: []},
     type: '',
     isRichSuggestion: false,
@@ -35,6 +37,18 @@ export function createAutocompleteMatch(): AutocompleteMatch {
   };
 }
 
+export function createAutocompleteResult(
+    modifiers: Partial<AutocompleteResult> = {}): AutocompleteResult {
+  const base: AutocompleteResult = {
+    input: stringToMojoString16(''),
+    matches: [],
+    suggestionGroupsMap: {},
+    smartComposeInlineHint: null,
+  };
+
+  return Object.assign(base, modifiers);
+}
+
 /**
  * Asserts the computed style value for an element.
  * @param name The name of the style to assert.
