@@ -258,6 +258,10 @@ IN_PROC_BROWSER_TEST_F(CrExtensionsItemsTest, CanUploadAsAccountExtension) {
   RunTestCase("CanUploadAsAccountExtension");
 }
 
+IN_PROC_BROWSER_TEST_F(CrExtensionsItemsTest, ShowErrorAsWarningsButtonLabel) {
+  RunTestCase("ShowErrorAsWarningsButtonLabel");
+}
+
 class CrExtensionsDetailViewTest : public ExtensionsBrowserTest {
  protected:
   void RunTestCase(const std::string& testCase) {
@@ -559,8 +563,6 @@ class CrExtensionsManagerTestWithMultipleExtensionTypesInstalled
   }
 };
 
-// TODO(crbug.com/392777363): Enable on desktop android.
-#if BUILDFLAG(ENABLE_EXTENSIONS)
 IN_PROC_BROWSER_TEST_F(
     CrExtensionsManagerTestWithMultipleExtensionTypesInstalled,
     ItemListVisibility) {
@@ -568,6 +570,8 @@ IN_PROC_BROWSER_TEST_F(
   RunTestCase("ItemListVisibility");
 }
 
+// TODO(crbug.com/439447730): Enable on desktop android.
+#if BUILDFLAG(ENABLE_EXTENSIONS)
 IN_PROC_BROWSER_TEST_F(
     CrExtensionsManagerTestWithMultipleExtensionTypesInstalled,
     SplitItems) {
@@ -638,7 +642,7 @@ class CrExtensionsManagerTestWithIdQueryParam
   }
 };
 
-// TODO(crbug.com/392777363): Enable on desktop android.
+// TODO(crbug.com/439447730): Enable on desktop android.
 #if BUILDFLAG(ENABLE_EXTENSIONS)
 IN_PROC_BROWSER_TEST_F(CrExtensionsManagerTestWithIdQueryParam,
                        UrlNavigationToDetails) {
@@ -726,7 +730,7 @@ class CrExtensionsErrorConsoleTest : public ExtensionSettingsTestBase {
   }
 };
 
-// TODO(crbug.com/392777363): Enable on desktop android.
+// TODO(crbug.com/439447730): Enable on desktop android.
 #if BUILDFLAG(ENABLE_EXTENSIONS)
 IN_PROC_BROWSER_TEST_F(CrExtensionsErrorConsoleTest, TestUpDownErrors) {
   SetDevModeEnabled(true);
@@ -840,6 +844,14 @@ IN_PROC_BROWSER_TEST_F(CrExtensionsErrorPageTest, ReloadItem) {
   RunTestCase("ReloadItem");
 }
 
+IN_PROC_BROWSER_TEST_F(CrExtensionsErrorPageTest, DevToolsButtonContentScript) {
+  RunTestCase("DevToolsButtonContentScript");
+}
+
+IN_PROC_BROWSER_TEST_F(CrExtensionsErrorPageTest, DevToolsButtonServiceWorker) {
+  RunTestCase("DevToolsButtonServiceWorker");
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // Extension Code Section Tests
 
