@@ -23,9 +23,19 @@ export interface PageElementTypes {
   testPermissionSwitch: HTMLButtonElement;
   openGlicSettings: HTMLButtonElement;
   openGlicSettingsHighlight: HTMLSelectElement;
+  pageMetadataNames: HTMLInputElement;
+  pageMetadataOpenTestPage: HTMLButtonElement;
+  pageMetadataRefreshTabs: HTMLButtonElement;
+  pageMetadataSection: HTMLFieldSetElement;
+  pageMetadataResult: HTMLTextAreaElement;
+  pageMetadataStatus: HTMLParagraphElement;
+  pageMetadataSubscribe: HTMLButtonElement;
+  pageMetadataTabsList: HTMLSelectElement;
+  pageMetadataUnsubscribe: HTMLButtonElement;
   microphoneSwitch: HTMLInputElement;
   geolocationSwitch: HTMLInputElement;
   tabContextSwitch: HTMLInputElement;
+  defaultTabContextSwitch: HTMLInputElement;
   newtabbn: HTMLButtonElement;
   reloadpage: HTMLButtonElement;
   getpagecontext: HTMLButtonElement;
@@ -132,6 +142,7 @@ export interface PageElementTypes {
   fetchPinned: HTMLButtonElement;
   shareCandidateQuery: HTMLInputElement;
   shareCandidates: HTMLElement;
+  enableShareCandidates: HTMLInputElement;
   unpin: HTMLButtonElement;
   viewChangedBtn: HTMLButtonElement;
   viewChangedCurrentView: HTMLSelectElement;
