@@ -58,9 +58,6 @@ suite('NewTabPageAppTest', () => {
       customLinksEnabled: false,
       shortcutsVisible: false,
     }));
-    handler.setResultFor('getBackgroundCollections', Promise.resolve({
-      collections: [],
-    }));
     handler.setResultFor('getDoodle', Promise.resolve({
       doodle: null,
     }));
@@ -775,7 +772,7 @@ suite('NewTabPageAppTest', () => {
       assertStyle(modules, 'display', 'none');
 
       // Act.
-      modules.dispatchEvent(new Event('modules-loaded'));
+      modules.dispatchEvent(new CustomEvent('modules-loaded', {detail: 1}));
       await microtasksFinished();
 
       // Assert.
@@ -1290,7 +1287,7 @@ suite('NewTabPageAppTest', () => {
                   'NewTabPage.ComposeEntrypoint.Click.UserTextPresent', true));
         });
 
-    test('Propogate composebox text when closed', async () => {
+    test('Propagate composebox text when closed', async () => {
       composeboxHandler.reset();
       $$(app, '#searchbox')!.dispatchEvent(new Event('open-composebox'));
       await microtasksFinished();
