@@ -8,7 +8,9 @@ import {PageCallbackRouter, PageHandlerRemote} from 'chrome://resources/cr_compo
 import type {PageRemote} from 'chrome://resources/cr_components/composebox/composebox.mojom-webui.js';
 import {FileUploadErrorType, FileUploadStatus} from 'chrome://resources/cr_components/composebox/composebox_query.mojom-webui.js';
 import {loadTimeData} from 'chrome://resources/js/load_time_data.js';
+import {stringToMojoString16} from 'chrome://resources/js/mojo_type_util.js';
 import {PageCallbackRouter as SearchboxPageCallbackRouter, PageHandlerRemote as SearchboxPageHandlerRemote} from 'chrome://resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
+import type {AutocompleteMatch, AutocompleteResult, PageRemote as SearchboxPageRemote} from 'chrome://resources/mojo/components/omnibox/browser/searchbox.mojom-webui.js';
 import {assertDeepEquals, assertEquals, assertFalse, assertTrue} from 'chrome://webui-test/chai_assert.js';
 import type {MetricsTracker} from 'chrome://webui-test/metrics_test_support.js';
 import {fakeMetricsPrivate} from 'chrome://webui-test/metrics_test_support.js';
@@ -17,6 +19,13 @@ import {eventToPromise, microtasksFinished} from 'chrome://webui-test/test_util.
 
 import {assertStyle, installMock} from '../test_support.js';
 
+enum Attributes {
+  SELECTED = 'selected',
+}
+
+const ADD_FILE_CONTEXT_FN = 'addFileContext';
+const ADD_TAB_CONTEXT_FN = 'addTabContext';
+
 function generateZeroId(): string {
   // Generate 128 bit unique identifier.
   const components = new Uint32Array(4);
@@ -29,6 +38,7 @@ suite('NewTabPageComposeboxTest', () => {
   let handler: TestMock<PageHandlerRemote>;
   let searchboxHandler: TestMock<SearchboxPageHandlerRemote>;
   let callbackRouterRemote: PageRemote;
+  let searchboxCallbackRouterRemote: SearchboxPageRemote;
   let metrics: MetricsTracker;
 
   setup(() => {
@@ -43,6 +53,9 @@ suite('NewTabPageComposeboxTest', () => {
     searchboxHandler = installMock(
         SearchboxPageHandlerRemote,
         mock => ComposeboxProxyImpl.getInstance().searchboxHandler = mock);
+    searchboxCallbackRouterRemote =
+        ComposeboxProxyImpl.getInstance()
+            .searchboxCallbackRouter.$.bindNewPipeAndPassRemote();
     metrics = fakeMetricsPrivate();
   });
 
@@ -55,7 +68,7 @@ suite('NewTabPageComposeboxTest', () => {
     const startTime = Date.now();
     return new Promise((resolve, reject) => {
       const checkCount = () => {
-        const currentCount = handler.getCallCount('addFile');
+        const currentCount = handler.getCallCount(ADD_FILE_CONTEXT_FN);
         if (currentCount === expectedCount) {
           resolve();
           return;
@@ -90,11 +103,75 @@ suite('NewTabPageComposeboxTest', () => {
     return mockFileChange;
   }
 
+  function createAutocompleteMatch(): AutocompleteMatch {
+    return {
+      a11yLabel: {data: []},
+      actions: [],
+      allowedToBeDefaultMatch: false,
+      isSearchType: false,
+      isEnterpriseSearchAggregatorPeopleType: false,
+      swapContentsAndDescription: false,
+      supportsDeletion: false,
+      suggestionGroupId: -1,  // Indicates a missing suggestion group Id.
+      contents: {data: []},
+      contentsClass: [{offset: 0, style: 0}],
+      description: {data: []},
+      descriptionClass: [{offset: 0, style: 0}],
+      destinationUrl: {url: ''},
+      inlineAutocompletion: {data: []},
+      fillIntoEdit: {data: []},
+      iconPath: '',
+      iconUrl: {url: ''},
+      imageDominantColor: '',
+      imageUrl: '',
+      isNoncannedAimSuggestion: false,
+      removeButtonA11yLabel: {data: []},
+      type: '',
+      isRichSuggestion: false,
+      isWeatherAnswerSuggestion: null,
+      answer: null,
+      tailSuggestCommonPrefix: null,
+    };
+  }
+
+  function createAutocompleteResult(
+      modifiers: Partial<AutocompleteResult> = {}): AutocompleteResult {
+    const base: AutocompleteResult = {
+      input: stringToMojoString16(''),
+      matches: [],
+      suggestionGroupsMap: {},
+      smartComposeInlineHint: null,
+    };
+
+    return Object.assign(base, modifiers);
+  }
+
+  function createSearchMatch(modifiers: Partial<AutocompleteMatch> = {}):
+      AutocompleteMatch {
+    return Object.assign(
+        createAutocompleteMatch(), {
+          isSearchType: true,
+          contents: stringToMojoString16('hello world'),
+          destinationUrl: {url: 'https://www.google.com/search?q=hello+world'},
+          fillIntoEdit: stringToMojoString16('hello world'),
+          type: 'search-suggest',
+        },
+        modifiers);
+  }
+
+  async function areMatchesShowing(): Promise<boolean> {
+    // Force a synchronous render.
+    await searchboxCallbackRouterRemote.$.flushForTesting();
+    await microtasksFinished();
+    return window.getComputedStyle(composeboxElement.$.matches).display !==
+        'none';
+  }
+
   async function uploadFileAndVerify(token: Object, file: File) {
     // Assert no files.
     assertEquals(composeboxElement.$.carousel.files.length, 0);
 
-    handler.setResultFor('addFile', Promise.resolve({token: token}));
+    handler.setResultFor(ADD_FILE_CONTEXT_FN, Promise.resolve({token: token}));
 
     // Act.
     const dataTransfer = new DataTransfer();
@@ -104,7 +181,7 @@ suite('NewTabPageComposeboxTest', () => {
     input.files = dataTransfer.files;
     input.dispatchEvent(getMockFileChangeEventForType(file.type));
 
-    await handler.whenCalled('addFile');
+    await handler.whenCalled(ADD_FILE_CONTEXT_FN);
     await microtasksFinished();
 
     assertEquals(handler.getCallCount('notifySessionStarted'), 1);
@@ -120,12 +197,12 @@ suite('NewTabPageComposeboxTest', () => {
     assertEquals(files[0]!.name, file.name);
 
     // Assert file is uploaded.
-    assertEquals(handler.getCallCount('addFile'), 1);
+    assertEquals(handler.getCallCount(ADD_FILE_CONTEXT_FN), 1);
 
     const fileBuffer = await file.arrayBuffer();
     const fileArray = Array.from(new Uint8Array(fileBuffer));
 
-    const [[fileInfo, fileData]] = handler.getArgs('addFile');
+    const [[fileInfo, fileData]] = handler.getArgs(ADD_FILE_CONTEXT_FN);
     assertEquals(fileInfo.fileName, file.name);
     assertDeepEquals(fileData.bytes, fileArray);
   }
@@ -133,7 +210,8 @@ suite('NewTabPageComposeboxTest', () => {
   test('clear functionality', async () => {
     createComposeboxElement();
     handler.setResultFor(
-        'addFile', Promise.resolve({token: {low: BigInt(1), high: BigInt(2)}}));
+        ADD_FILE_CONTEXT_FN,
+        Promise.resolve({token: {low: BigInt(1), high: BigInt(2)}}));
 
     // Check submit button disabled.
     assertStyle(composeboxElement.$.submitIcon, 'cursor', 'default');
@@ -146,7 +224,7 @@ suite('NewTabPageComposeboxTest', () => {
     composeboxElement.$.fileInput.files = dataTransfer.files;
     composeboxElement.$.fileInput.dispatchEvent(new Event('change'));
 
-    await handler.whenCalled('addFile');
+    await handler.whenCalled(ADD_FILE_CONTEXT_FN);
     await microtasksFinished();
 
     // Check submit button enabled and file uploaded.
@@ -205,7 +283,7 @@ suite('NewTabPageComposeboxTest', () => {
               assertTrue(!!announcement);
               assertEquals(announcement.detail.messages.length, 1);
 
-              callbackRouterRemote.onFileUploadStatusChanged(
+              callbackRouterRemote.onContextualInputStatusChanged(
                   id, FileUploadStatus.kUploadSuccessful, null);
               await callbackRouterRemote.$.flushForTesting();
 
@@ -240,7 +318,7 @@ suite('NewTabPageComposeboxTest', () => {
     await microtasksFinished();
 
     // Assert no files uploaded or rendered on the carousel
-    assertEquals(handler.getCallCount('addFile'), 0);
+    assertEquals(handler.getCallCount(ADD_FILE_CONTEXT_FN), 0);
     const files = composeboxElement.$.carousel.files;
     assertEquals(files.length, 0);
     assertEquals(
@@ -267,7 +345,7 @@ suite('NewTabPageComposeboxTest', () => {
     await microtasksFinished();
 
     // Assert no files uploaded or rendered on the carousel
-    assertEquals(handler.getCallCount('addFile'), 0);
+    assertEquals(handler.getCallCount(ADD_FILE_CONTEXT_FN), 0);
     const files = composeboxElement.$.carousel.files;
     assertEquals(files.length, 0);
     assertEquals(
@@ -297,7 +375,7 @@ suite('NewTabPageComposeboxTest', () => {
           const file = new File(['foo'], 'foo.jpg', {type: 'image/jpeg'});
           await uploadFileAndVerify(id, file);
 
-          callbackRouterRemote.onFileUploadStatusChanged(
+          callbackRouterRemote.onContextualInputStatusChanged(
               id, fileUploadStatus as FileUploadStatus,
               fileUploadErrorType as FileUploadErrorType | null);
           await callbackRouterRemote.$.flushForTesting();
@@ -311,7 +389,8 @@ suite('NewTabPageComposeboxTest', () => {
   test('upload pdf', async () => {
     createComposeboxElement();
     handler.setResultFor(
-        'addFile', Promise.resolve({token: {low: BigInt(1), high: BigInt(2)}}));
+        ADD_FILE_CONTEXT_FN,
+        Promise.resolve({token: {low: BigInt(1), high: BigInt(2)}}));
 
     // Assert no files.
     assertEquals(composeboxElement.$.carousel.files.length, 0);
@@ -323,7 +402,7 @@ suite('NewTabPageComposeboxTest', () => {
     composeboxElement.$.fileInput.files = dataTransfer.files;
     composeboxElement.$.fileInput.dispatchEvent(new Event('change'));
 
-    await handler.whenCalled('addFile');
+    await handler.whenCalled(ADD_FILE_CONTEXT_FN);
     await microtasksFinished();
 
     // Assert one pdf file.
@@ -339,8 +418,8 @@ suite('NewTabPageComposeboxTest', () => {
     const fileArray = Array.from(new Uint8Array(fileBuffer));
 
     // Assert file is uploaded.
-    assertEquals(handler.getCallCount('addFile'), 1);
-    const [[fileInfo, fileData]] = handler.getArgs('addFile');
+    assertEquals(handler.getCallCount(ADD_FILE_CONTEXT_FN), 1);
+    const [[fileInfo, fileData]] = handler.getArgs(ADD_FILE_CONTEXT_FN);
     assertEquals(fileInfo.fileName, 'foo.pdf');
     assertDeepEquals(fileData.bytes, fileArray);
   });
@@ -348,7 +427,7 @@ suite('NewTabPageComposeboxTest', () => {
   test('delete file', async () => {
     createComposeboxElement();
     let i = 0;
-    handler.setResultMapperFor('addFile', () => {
+    handler.setResultMapperFor(ADD_FILE_CONTEXT_FN, () => {
       i += 1;
       return Promise.resolve(
           {token: {low: BigInt(i + 1), high: BigInt(i + 2)}});
@@ -393,8 +472,8 @@ suite('NewTabPageComposeboxTest', () => {
 
     // Assert.
     assertEquals(composeboxElement.$.carousel.files.length, 1);
-    assertEquals(handler.getCallCount('deleteFile'), 1);
-    const [idArg] = handler.getArgs('deleteFile');
+    assertEquals(handler.getCallCount('deleteContext'), 1);
+    const [idArg] = handler.getArgs('deleteContext');
     assertEquals(idArg, deletedId);
   });
 
@@ -442,7 +521,8 @@ suite('NewTabPageComposeboxTest', () => {
     loadTimeData.overrideValues({'composeboxShowPdfUpload': true});
     createComposeboxElement();
     handler.setResultFor(
-        'addFile', Promise.resolve({token: {low: BigInt(1), high: BigInt(2)}}));
+        ADD_FILE_CONTEXT_FN,
+        Promise.resolve({token: {low: BigInt(1), high: BigInt(2)}}));
 
     // File upload buttons are not disabled when there are no files.
     assertFalse(composeboxElement.$.fileUploadButton.disabled);
@@ -455,7 +535,7 @@ suite('NewTabPageComposeboxTest', () => {
     composeboxElement.$.fileInput.files = dataTransfer.files;
     composeboxElement.$.fileInput.dispatchEvent(new Event('change'));
 
-    await handler.whenCalled('addFile');
+    await handler.whenCalled(ADD_FILE_CONTEXT_FN);
     await microtasksFinished();
 
     // Assert.
@@ -500,23 +580,28 @@ suite('NewTabPageComposeboxTest', () => {
   test('submit button click leads to handler called', async () => {
     createComposeboxElement();
     // Assert.
-    assertEquals(handler.getCallCount('submitQuery'), 0);
+    assertEquals(searchboxHandler.getCallCount('openAutocompleteMatch'), 0);
 
     // Arrange.
     composeboxElement.$.input.value = 'test';
     composeboxElement.$.input.dispatchEvent(new Event('input'));
+    const matches = [createSearchMatch({allowedToBeDefaultMatch: true})];
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          input: stringToMojoString16('test'),
+          matches,
+        }));
+    await searchboxCallbackRouterRemote.$.flushForTesting();
     await microtasksFinished();
     composeboxElement.$.submitIcon.click();
     await microtasksFinished();
 
     // Assert call occurs.
-    assertEquals(handler.getCallCount('submitQuery'), 1);
+    assertEquals(searchboxHandler.getCallCount('openAutocompleteMatch'), 1);
   });
 
   test('empty input does not lead to submission', async () => {
     createComposeboxElement();
-    // Assert.
-    assertEquals(handler.getCallCount('submitQuery'), 0);
 
     // Arrange.
     composeboxElement.$.input.value = '';
@@ -527,6 +612,7 @@ suite('NewTabPageComposeboxTest', () => {
 
     // Assert call does not occur.
     assertEquals(handler.getCallCount('submitQuery'), 0);
+    assertEquals(searchboxHandler.getCallCount('openAutocompleteMatch'), 0);
   });
 
   test('submit button is disabled', async () => {
@@ -542,11 +628,18 @@ suite('NewTabPageComposeboxTest', () => {
   test('keydown submit only works for enter', async () => {
     createComposeboxElement();
     // Assert.
-    assertEquals(handler.getCallCount('submitQuery'), 0);
+    assertEquals(searchboxHandler.getCallCount('openAutocompleteMatch'), 0);
 
     // Arrange.
     composeboxElement.$.input.value = 'test';
     composeboxElement.$.input.dispatchEvent(new Event('input'));
+    const matches = [createSearchMatch({allowedToBeDefaultMatch: true})];
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          input: stringToMojoString16('test'),
+          matches: matches,
+        }));
+    await searchboxCallbackRouterRemote.$.flushForTesting();
     await microtasksFinished();
     const shiftEnterEvent = new KeyboardEvent('keydown', {
       key: 'Enter',
@@ -558,7 +651,7 @@ suite('NewTabPageComposeboxTest', () => {
     await microtasksFinished();
 
     // Assert.
-    assertEquals(handler.getCallCount('submitQuery'), 0);
+    assertEquals(searchboxHandler.getCallCount('openAutocompleteMatch'), 0);
 
     const enterEvent = new KeyboardEvent('keydown', {
       key: 'Enter',
@@ -569,7 +662,7 @@ suite('NewTabPageComposeboxTest', () => {
     await microtasksFinished();
 
     // Assert call occurs.
-    assertEquals(handler.getCallCount('submitQuery'), 1);
+    assertEquals(searchboxHandler.getCallCount('openAutocompleteMatch'), 1);
   });
 
   test('clear button title changes with input', async () => {
@@ -599,4 +692,253 @@ suite('NewTabPageComposeboxTest', () => {
     // Restore.
     loadTimeData.overrideValues({composeboxShowZps: false});
   });
+
+  test('dropdown shows when suggestions enabled', async () => {
+    loadTimeData.overrideValues(
+        {composeboxShowZps: true, composeboxShowTypedSuggest: true});
+    createComposeboxElement();
+    await microtasksFinished();
+
+    // Add zps input.
+    composeboxElement.$.input.value = '';
+    composeboxElement.$.input.dispatchEvent(new Event('input'));
+
+    // Composebox dropdown should show in zps.
+    const composeboxDropdown =
+        composeboxElement.shadowRoot.querySelector<HTMLElement>('#matches');
+    assertTrue(!!composeboxDropdown);
+    assertFalse(composeboxDropdown.hidden);
+
+    // Dropdown should not show for input with only spaces.
+    composeboxElement.$.input.value = ' ';
+    composeboxElement.$.input.dispatchEvent(new Event('input'));
+    await microtasksFinished();
+    assertTrue(composeboxDropdown.hidden);
+
+    // Dropdown should show with text.
+    composeboxElement.$.input.value = ' hello';
+    composeboxElement.$.input.dispatchEvent(new Event('input'));
+    await microtasksFinished();
+    assertFalse(composeboxDropdown.hidden);
+
+    // Restore.
+    loadTimeData.overrideValues(
+        {composeboxShowZps: false, composeboxShowTypedSuggest: false});
+  });
+
+  test('arrow up/down moves selection / focus', async () => {
+    loadTimeData.overrideValues({composeboxShowZps: true});
+    createComposeboxElement();
+    await microtasksFinished();
+
+    // Add zps input.
+    composeboxElement.$.input.value = '';
+    composeboxElement.$.input.dispatchEvent(new Event('input'));
+
+    const matches = [
+      createSearchMatch(),
+      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+    ];
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          matches: matches,
+        }));
+
+    assertTrue(await areMatchesShowing());
+
+    const matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
+        'ntp-composebox-match');
+    assertEquals(2, matchEls.length);
+
+    const arrowDownEvent = new KeyboardEvent('keydown', {
+      bubbles: true,
+      cancelable: true,
+      composed: true,  // So it propagates across shadow DOM boundary.
+      key: 'ArrowDown',
+    });
+    composeboxElement.$.input.dispatchEvent(arrowDownEvent);
+    await microtasksFinished();
+    assertTrue(arrowDownEvent.defaultPrevented);
+
+    // First match remains selected and does not get focus while focus is in the
+    // input.
+    assertTrue(matchEls[0]!.hasAttribute(Attributes.SELECTED));
+    assertEquals('hello world', composeboxElement.$.input.value);
+    assertEquals(
+        composeboxElement.$.input, composeboxElement.shadowRoot.activeElement);
+
+    // Move the focus to the second match.
+    matchEls[1]!.focus();
+    matchEls[1]!.dispatchEvent(new Event('focusin', {
+      bubbles: true,
+      cancelable: true,
+      composed: true,  // So it propagates across shadow DOM boundary.
+    }));
+    await microtasksFinished();
+
+    // Second match is selected and has focus.
+    assertTrue(matchEls[1]!.hasAttribute(Attributes.SELECTED));
+    assertEquals('hello world 2', composeboxElement.$.input.value);
+    assertEquals(
+        matchEls[1], composeboxElement.$.matches.shadowRoot.activeElement);
+
+    const arrowUpEvent = new KeyboardEvent('keydown', {
+      bubbles: true,
+      cancelable: true,
+      composed: true,  // So it propagates across shadow DOM boundary.
+      key: 'ArrowUp',
+    });
+
+    matchEls[1]!.dispatchEvent(arrowUpEvent);
+    await microtasksFinished();
+    assertTrue(arrowUpEvent.defaultPrevented);
+
+    // First match gets selected and gets focus while focus is in the matches.
+    assertTrue(matchEls[0]!.hasAttribute(Attributes.SELECTED));
+    assertEquals('hello world', composeboxElement.$.input.value);
+    assertEquals(
+        matchEls[0], composeboxElement.$.matches.shadowRoot.activeElement);
+
+    // Restore.
+    loadTimeData.overrideValues({composeboxShowZps: false});
+  });
+
+  test('smart compose response added', async () => {
+    createComposeboxElement();
+    await microtasksFinished();
+
+    // Add input.
+    composeboxElement.$.input.value = 'smart ';
+    composeboxElement.$.input.dispatchEvent(new Event('input'));
+
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          input: stringToMojoString16('smart '),
+          matches: [],
+          smartComposeInlineHint: stringToMojoString16('compose'),
+        }));
+    await microtasksFinished();
+
+    assertEquals('compose', composeboxElement.getSmartComposeForTesting());
+  });
+
+  test('composebox does not open match when only file present', async () => {
+    createComposeboxElement();
+
+    assertEquals(handler.getCallCount('submitQuery'), 0);
+    const token = {low: BigInt(1), high: BigInt(2)};
+    await uploadFileAndVerify(
+        token, new File(['foo'], 'foo.jpg', {type: 'image/jpeg'}));
+
+    composeboxElement.$.submitIcon.click();
+    await microtasksFinished();
+
+    // Assert call occurs.
+    assertEquals(handler.getCallCount('submitQuery'), 1);
+    assertEquals(searchboxHandler.getCallCount('openAutocompleteMatch'), 0);
+  });
+
+  test('delete button removes match', async () => {
+    loadTimeData.overrideValues({composeboxShowZps: true});
+    createComposeboxElement();
+    await microtasksFinished();
+
+    const matches = [
+      createSearchMatch(),
+      createSearchMatch({fillIntoEdit: stringToMojoString16('hello world 2')}),
+    ];
+    searchboxCallbackRouterRemote.autocompleteResultChanged(
+        createAutocompleteResult({
+          input: stringToMojoString16(''),
+          matches,
+          suggestionGroupsMap: {},
+        }));
+
+    assertTrue(await areMatchesShowing());
+
+    const matchEls = composeboxElement.$.matches.shadowRoot.querySelectorAll(
+        'ntp-composebox-match');
+    assertEquals(2, matchEls.length);
+    const matchEl = matchEls[0];
+    assertTrue(!!matchEl);
+
+    const matchIndex = 0;
+    const destinationUrl = {url: 'http://google.com'};
+    matchEl.matchIndex = matchIndex;
+    matchEl.match.destinationUrl = destinationUrl;
+
+    // By pressing 'Enter' on the button.
+    const keydownEvent = (new KeyboardEvent('keydown', {
+      bubbles: true,
+      cancelable: true,
+      composed: true,
+      key: 'Enter',
+    }));
+    assertTrue(!!matchEl.$.remove);
+    matchEl.$.remove.dispatchEvent(keydownEvent);
+    assertTrue(keydownEvent.defaultPrevented);
+    const keydownArgs =
+        await searchboxHandler.whenCalled('deleteAutocompleteMatch');
+    await microtasksFinished();
+    assertEquals(matchIndex, keydownArgs[0]);
+    assertEquals(destinationUrl, keydownArgs[1]);
+    assertEquals(1, searchboxHandler.getCallCount('deleteAutocompleteMatch'));
+    // Pressing the 'Enter' button doesn't accidentally trigger navigation.
+    assertEquals(0, handler.getCallCount('submitQuery'));
+    searchboxHandler.reset();
+    handler.reset();
+
+    matchEl.$.remove.click();
+    const clickArgs =
+        await searchboxHandler.whenCalled('deleteAutocompleteMatch');
+    await microtasksFinished();
+    assertEquals(matchIndex, clickArgs[0]);
+    assertEquals(destinationUrl, clickArgs[1]);
+    assertEquals(1, searchboxHandler.getCallCount('deleteAutocompleteMatch'));
+    // Clicking the button doesn't accidentally trigger navigation.
+    assertEquals(0, handler.getCallCount('submitQuery'));
+  });
+
+  suite('Context menu', () => {
+    suiteSetup(() => {
+      loadTimeData.overrideValues({
+        composeboxShowContextMenu: true,
+      });
+    });
+
+    test('context button replaces upload container', () => {
+      createComposeboxElement();
+
+      const uploadContainer = $$(composeboxElement, '#uploadContainer');
+      assertFalse(!!uploadContainer);
+      const contextMenuButton = $$(composeboxElement, '#contextEntrypoint');
+      assertTrue(!!contextMenuButton);
+    });
+
+    test('add tab context', async () => {
+      createComposeboxElement();
+      handler.setResultFor(
+          ADD_TAB_CONTEXT_FN,
+          Promise.resolve({token: {low: BigInt(1), high: BigInt(2)}}));
+
+      // Assert no files.
+      assertEquals(composeboxElement.$.carousel.files.length, 0);
+
+      const contextMenuButton = $$(composeboxElement, '#contextEntrypoint');
+      assertTrue(!!contextMenuButton);
+      const sampleTabTitle = 'Sample Tab';
+      contextMenuButton.dispatchEvent(new CustomEvent('add-tab-context', {
+        detail: {id: 1, title: sampleTabTitle},
+        bubbles: true,
+        composed: true,
+      }));
+
+      await handler.whenCalled(ADD_TAB_CONTEXT_FN);
+      await microtasksFinished();
+      const files = composeboxElement.$.carousel.files;
+      assertEquals(files.length, 1);
+      assertEquals(files[0]!.type, 'tab');
+      assertEquals(files[0]!.name, sampleTabTitle);
+    });
+  });
 });
