@@ -85,6 +85,8 @@ export class FakeReadingMode {
   private maxNodeId: number = 5;
 
   fetchedImages: number[] = [];
+  wordsSeen: number = 0;
+  wordsHeard: number = 0;
 
   // Returns whether the reading highlight is currently on.
   isHighlightOn(): boolean {
@@ -138,6 +140,11 @@ export class FakeReadingMode {
     return 'foo';
   }
 
+  // Returns the alt text of the AXNode for the provided AXNodeID.
+  getAltText(_nodeId: number): string {
+    return 'foo';
+  }
+
   // Returns true if the text node / element should be bolded.
   shouldBold(_nodeId: number): boolean {
     return false;
@@ -333,6 +340,16 @@ export class FakeReadingMode {
     return true;
   }
 
+  // Called when the number of words seen by a reading mode user changes.
+  updateWordsSeen(wordsSeen: number) {
+    this.wordsSeen = wordsSeen;
+  }
+
+  // Called when the number of words heard by a read aloud user changes.
+  updateWordsHeard(wordsHeard: number) {
+    this.wordsHeard = wordsHeard;
+  }
+
   ////////////////////////////////////////////////////////////////
   // Implemented in read_anything/app.ts and called by native c++.
   ////////////////////////////////////////////////////////////////
@@ -367,25 +384,10 @@ export class FakeReadingMode {
   // position, but we should be able to remove this in the future.
   initAxPositionWithNode(_startingNodeId: number): void {}
 
-  // Gets the starting text index for the current Read Aloud text segment
-  // for the given node. nodeId should be a node returned by getCurrentText.
-  // Returns -1 if the node is invalid.
-  getCurrentTextStartIndex(_nodeId: number): number {
-    return 0;
-  }
-
-  // Gets the ending text index for the current Read Aloud text segment
-  // for the given node. nodeId should be a node returned by getCurrentText or
-  // getPreviousText. Returns -1 if the node is invalid.
-  getCurrentTextEndIndex(_nodeId: number): number {
-    return 5;
-  }
-
-  // Gets the nodes of the  next text that should be spoken and highlighted.
-  // Use getCurrentTextStartIndex and getCurrentTextEndIndex to get the bounds
-  // for text associated with these nodes.
-  getCurrentText(): number[] {
-    return [2];
+  // Gets the text content of the next text that should be spoken and
+  // highlighted.
+  getCurrentTextContent() {
+    return 'default text content';
   }
 
   // Increments the processed_granularity_index_ in ReadAnythingAppModel,
@@ -446,6 +448,16 @@ export class FakeReadingMode {
     return [];
   }
 
+  // Returns a list of node ids and ranges (start and length) associated with
+  // the full next text segment to speak and highlight. Note that a highlight
+  // can span over multiple nodes in certain cases. This is different from
+  // getHighlightForCurrentSegmentIndex in that this returns the full sentence
+  // whereas the other returns a segment (word or phrase) within the sentence.
+  getCurrentTextSegments():
+      Array<{nodeId: number, start: number, length: number}> {
+    return [];
+  }
+
   // Resets the granularity index.
   resetGranularityIndex() {}
 }
